@@ -8,13 +8,11 @@ mod windows;
 #[cfg(target_os="windows")]
 use self::windows::trace_route;
 
-mod node;
-pub use node::*;
-
 mod tracer;
 pub use tracer::*;
 
 use std::time::Duration;
+use crate::node::Node;
 
 /// Exit status of traceroute
 #[derive(Clone, Debug)]
@@ -27,7 +25,7 @@ pub enum TraceStatus {
 /// Result of traceroute
 #[derive(Clone, Debug)]
 pub struct TraceResult {
-    pub nodes: Vec<node::Node>,
+    pub nodes: Vec<Node>,
     pub status: TraceStatus,
-    pub trace_time: Duration,
+    pub probe_time: Duration,
 }
